@@ -33,7 +33,6 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "multisite",
         "edc_appointment.apps.AppConfig",
         "edc_action_item.apps.AppConfig",
-        "adverse_event_app.apps.AppConfig",
         "edc_adverse_event.apps.AppConfig",
         "edc_auth.apps.AppConfig",
         "edc_notification.apps.AppConfig",
@@ -58,7 +57,10 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_timepoint.apps.AppConfig",
         "edc_visit_schedule.apps.AppConfig",
         "edc_visit_tracking.apps.AppConfig",
+        "edc_listboard.apps.AppConfig",
+        "edc_review_dashboard.apps.AppConfig",
         "edc_subject_dashboard.apps.AppConfig",
+        "adverse_event_app.apps.AppConfig",
         "edc_dashboard.apps.AppConfig",
     ],
     add_dashboard_middleware=True,
